==> koffice-trinity-3.5.13.2.tar.xz: koffice-trinity-3.5.13.2/kspread/kspread_factory.h <==
/* This file is part of the KDE project
   Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
*/

#ifndef KSPREAD_FACTORY_H
#define KSPREAD_FACTORY_H

#include <KoFactory.h>

class KAboutData;
class DCOPObject;

namespace KSpread
{

class Factory : public KoFactory
{
    Q_OBJECT
  TQ_OBJECT
public:
    Factory( TQObject* parent = 0, const char* name = 0 );
    ~Factory();

    virtual KParts::Part *createPartObject( TQWidget *parentWidget = 0, const char *widgetName = 0, TQObject *parent = 0, const char *name = 0, const char *classname = "KoDocument", const TQStringList &args = TQStringList() );

    static KInstance* global();

    // _Creates_ a KAboutData but doesn't keep ownership
    static KAboutData* aboutData();

    static DCOPObject* dcopObject();

private:
    static KInstance* s_global;
    static DCOPObject* s_dcopObject;
    static KAboutData* s_aboutData;
};

} // namespace KSpread

#endif

==> koffice-trinity_14.0.5.orig.tar.xz: koffice-trinity-14.0.5/kspread/kspread_factory.h <==
/* This file is part of the KDE project
   Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
*/

#ifndef KSPREAD_FACTORY_H
#define KSPREAD_FACTORY_H

#include <KoFactory.h>

class TDEAboutData;
class DCOPObject;

namespace KSpread
{

class Factory : public KoFactory
{
    Q_OBJECT
  
public:
    Factory( TQObject* parent = 0, const char* name = 0 );
    ~Factory();

    virtual KParts::Part *createPartObject( TQWidget *parentWidget = 0, const char *widgetName = 0, TQObject *parent = 0, const char *name = 0, const char *classname = "KoDocument", const TQStringList &args = TQStringList() );

    static TDEInstance* global();

    // _Creates_ a TDEAboutData but doesn't keep ownership
    static TDEAboutData* aboutData();

    static DCOPObject* dcopObject();

private:
    static TDEInstance* s_global;
    static DCOPObject* s_dcopObject;
    static TDEAboutData* s_aboutData;
};

} // namespace KSpread

#endif
